@@ -21,9 +21,7 @@ get_type_prob <- function(model, P = NULL, parameters = NULL) {
         P <- get_parameter_matrix(model)
 
     # Type probabilities
-    P.lambdas <- P * parameters + 1 - P
-    apply(P.lambdas, 2, prod)
-
+    get_type_prob_c(P = as.matrix(P), parameters = parameters)
 }
 
 #' Draw matrix of type probabilities, before or after estimation
@@ -59,9 +57,9 @@ get_type_prob_multiple <- function(model, using = "priors", parameters = NULL, n
     if (is.null(param_dist))
         param_dist <- get_param_dist(model, using, n_draws = n_draws)
 
-    # Seem to be no speed gains via matrix multiplication instead of apply
-    apply(param_dist, 1, function(j) get_type_prob(model, parameters = j, P = P))
-
+    res <- get_type_prob_multiple_c(params = param_dist, P = as.matrix(P))
+    rownames(res) <- colnames(P)
+    return(res)
 }
 
 
