@@ -34,25 +34,28 @@
 #' # Throws error unless compact data indicated:
 #'
 #' model_3 <- update_model(model, data_short)
-#'}
-#'\donttest{
 #' model_4 <- update_model(model, data_short, data_type = 'compact')
 #'
-#' # It is possible to implement updating without data, in which case the posterior
-#' # is a stan object that reflects the prior
+#' # It is possible to implement updating without data, in which
+#' # case the posterior is a stan object that reflects the prior
 #' model_5 <- update_model(model)
 #'
 #'
 #' # Censored data types
 #' make_model("X->Y") %>%
-#'   update_model(data.frame(X=c(1,1), Y=c(1,1)), censored_types = c("X1Y0")) %>%
+#'   update_model(data.frame(X=c(1,1), Y=c(1,1)),
+#'   censored_types = c("X1Y0"),
+#'   init_r = 1) %>%
 #'   query_model(te("X", "Y"), using = "posteriors")
 #'
-#'# Censored data: Learning nothing
+#' # Censored data: Learning nothing
 #' make_model("X->Y") %>%
-#'   update_model(data.frame(X=c(1,1), Y=c(1,1)), censored_types = c("X1Y0", "X0Y0", "X0Y1")) %>%
+#'   update_model(data.frame(X=c(1,1), Y=c(1,1)),
+#'   censored_types = c("X1Y0", "X0Y0", "X0Y1"),
+#'   init_r = 1) %>%
 #'   query_model(te("X", "Y"), using = "posteriors")
-#'   }
+#'}
+
 
 update_model <- function(model, data = NULL, data_type = "long", keep_fit = FALSE,
                          keep_transformed = TRUE, censored_types = NULL, ...) {
@@ -92,7 +95,15 @@ update_model <- function(model, data = NULL, data_type = "long", keep_fit = FALS
                                 data = data_events,
                                 keep_transformed = keep_transformed*1)
 
-    # Parmpa goes to 0 for data types that never get to be observed
+    if(stan_data$n_nodes == 1){
+      stan_data$n_param_each <- as.array(stan_data$n_param_each)
+      stan_data$l_starts <- as.array(stan_data$l_starts)
+      stan_data$l_ends <- as.array(stan_data$l_ends)
+      stan_data$node_starts <- as.array(stan_data$node_starts)
+      stan_data$node_ends <- as.array(stan_data$node_ends)
+    }
+
+    # Parmap goes to 0 for data types that never get to be observed
     if(!is.null(censored_types))
     stan_data$parmap[, censored_types] <- 0
 
@@ -107,7 +118,7 @@ update_model <- function(model, data = NULL, data_type = "long", keep_fit = FALS
     if(keep_fit) model$stan_objects$stan_fit <- newfit
 
     model$posterior_distribution <- extract(newfit, pars = "lambdas")$lambdas
-    colnames(model$posterior_distribution) <- get_parameter_names(model)
+        colnames(model$posterior_distribution) <- get_parameter_names(model)
 
     model$stan_objects$type_distribution <- extract(newfit, pars = "prob_of_types")$prob_of_types
         colnames(model$stan_objects$type_distribution) <- colnames(stan_data$P)
@@ -116,5 +127,7 @@ update_model <- function(model, data = NULL, data_type = "long", keep_fit = FALS
         colnames(model$stan_objects$w_full) <- rownames(stan_data$E)
 
     model
+
 }
 
+
