@@ -1,12 +1,15 @@
 
-.runThisTest <- Sys.getenv("RunAllRcppTests") == "yes"
 
-if (.runThisTest) {
+
+
 
 context("Testing get_event_prob")
 
+testthat::skip_on_cran()
 testthat::test_that(
+
 	desc = "Testing warnings",
+
 	code = {
 		model <- make_model("X -> Y")
 		expect_error(get_event_prob(model = model, parameters = rnorm(6)),"Negative arguments for parameters not allowed")
@@ -15,7 +18,9 @@ testthat::test_that(
 
 
 testthat::test_that(
+
 	desc = "Testing hack",
+
 	code = {
 		model <- make_model("X -> Y") %>%
 			set_restrictions(c("(X[]==1)", "(Y[X=.]==1)"))
@@ -23,4 +28,4 @@ testthat::test_that(
 	}
 )
 
-}
+
