@@ -1,11 +1,12 @@
 
 
-.runThisTest <- Sys.getenv("RunAllRcppTests") == "yes"
 
-if (.runThisTest) {
+
+
 
 context(desc = "Testing layering")
 
+testthat::skip_on_cran()
 models <- c("X -> Y",
 						"X -> Y <- M",
 						"C -> Y <- M; X -> Y ")
@@ -15,27 +16,29 @@ restrictions <- c("Y[X=0] == 1", "Y[X=0, M = 0] > Y[X=1, M = 1]", "Y[X = 0, C =
 
 for(i in length(models)){
 	testthat::test_that(
+
 		desc = "Layering confounds and restrictions work in both directions",
+
 		code = {
 
 			model1 <- make_model(models[i]) %>%
-				set_confound(list(X = "Y[X=1]==1"))%>%
+			  set_confound("X <-> Y")%>%
 				set_restrictions(restrictions[i])
 
 			model2 <- make_model(models[i])%>%
 				set_restrictions(restrictions[i]) %>%
-				set_confound(list(X = "Y[X=1]==1"))
+				set_confound("X <-> Y")
 
 			expect_equal(nrow(get_causal_types(model1)), nrow(get_causal_types(model2)))
 
 
 			model1 <- make_model(models[i]) %>%
-				set_confound(list(X = "Y[X=1]==1"))%>%
+			  set_confound("X <-> Y") %>%
 				set_restrictions(restrictions[i], keep = TRUE)
 
 			model2 <- make_model(models[i])%>%
 				set_restrictions(restrictions[i], keep = TRUE) %>%
-				set_confound(list(X = "Y[X=1]==1"))
+			  set_confound("X <-> Y")
 
 			expect_equal(nrow(get_causal_types(model1)), nrow(get_causal_types(model2)))
 
@@ -49,7 +52,9 @@ for(i in length(models)){
 
 
 testthat::test_that(
+
 	desc = "Layering restrictions and P matrix",
+
 	code = {
 
 
@@ -65,4 +70,4 @@ testthat::test_that(
 		expect_equal(ncol(model_a$P), ncol(model_b$P))
 		})
 
-}
+
