@@ -1,12 +1,15 @@
 
-.runThisTest <- Sys.getenv("RunAllRcppTests") == "yes"
 
-if (.runThisTest) {
+
+
 
 context("Make_models")
 
+testthat::skip_on_cran()
 testthat::test_that(
+
 	desc = "Print and summary functions",
+
 	code = {
 		model <- make_model("X -> Y")
 		out <- capture.output(CausalQueries:::print.causal_model(model))
@@ -25,4 +28,4 @@ testthat::test_that(
 )
 
 
-}
+
