@@ -1,16 +1,19 @@
 
 
-.runThisTest <- Sys.getenv("RunAllRcppTests") == "yes"
 
-if (.runThisTest) {
+
+
 
 context("Set_prior_distribution")
 
+testthat::skip_on_cran()
 testthat::test_that(
+
 	desc = "Check messages.",
+
 	code = {
 		expect_message(make_model("X -> Y") %>% get_prior_distribution(3))
 		expect_equal(make_model("X -> Y") %>% set_prior_distribution(n_draws = 10) %>% get_prior_distribution() %>% nrow(), 10)
 	}
 )
-}
+
