@@ -36,17 +36,22 @@ testthat::test_that(
 	code = {
 	  model <- CausalQueries::make_model("X -> Y")
 	  out <- set_priors(model = model, alphas = c(0.5,0.25), alter_at = "node == 'X' & nodal_type %in% c('0','1')")
-	  expect_equal(out$parameters_df$priors, c(0.5,0.25,1,1,1,1))
+	  expect_equal(out$parameters_df$priors, c(X.0 = 0.5,X.1 = 0.25, Y.00=1,Y.10 = 1,Y.01 = 1, Y.11 = 1))
+
 	  out <- set_priors(model = model, alphas = c(0.5,0.25), node = "X", nodal_type = c("0","1"))
-	  expect_equal(out$parameters_df$priors, c(0.5,0.25,1,1,1,1))
+	  expect_equal(out$parameters_df$priors, c(X.0 = 0.5,X.1 = 0.25, Y.00=1,Y.10 = 1,Y.01 = 1, Y.11 = 1))
+
 	  out <- set_priors(model = model, alphas = 0.5, param_names = "X.0")
-	  expect_equal(out$parameters_df$priors, c(0.5,1,1,1,1,1))
+	  expect_equal(out$parameters_df$priors, c(X.0 = 0.5,X.1 = 1, Y.00=1,Y.10 = 1,Y.01 = 1, Y.11 = 1))
 
 	  model <- CausalQueries::make_model("X -> Y; X <-> Y")
 	  out <- set_priors(mode = model, alphas = c(0.5,0.25), node = "Y", nodal_type = c("00","01"), given = "X.0", param_set = "Y.X.0")
-	  expect_equal(out$parameters_df$priors, c(1,1,0.5,1,0.25,1,1,1,1,1))
+	  expect_equal(out$parameters_df$priors, c(X.0=1,X.1 = 1, Y.00_X.0 = .5,Y.10_X.0 = 1, Y.01_X.0 = .25,
+	    Y.11_X.0 = 1,Y.00_X.1 =  1, Y.10_X.1 = 1,Y.01_X.1 = 1,Y.11_X.1 = 1))
+
 	  out <- set_priors(model = model, alphas = c(0.5,0.25), statement = "Y[X=1] > Y[X=0]")
-	  expect_equal(out$parameters_df$priors, c(1,1,1,1,0.5,1,1,1,0.25,1))
+	  expect_equal(out$parameters_df$priors, c(X.0=1,X.1 = 1,Y.00_X.0 = 1,Y.10_X.0 = 1, Y.01_X.0 = 0.5,
+	                                           Y.11_X.0 = 1,Y.00_X.1 =  1, Y.10_X.1 = 1,Y.01_X.1 = 0.25,Y.11_X.1 = 1))
 	}
 )
 
