@@ -1,7 +1,4 @@
 
-.runThisTest <- Sys.getenv("RunAllRcppTests") == "yes"
-
-if (.runThisTest) {
 
 context("Tests for type_helpers")
 
@@ -12,4 +9,3 @@ testthat::test_that(
 		expect_equal(add_wildcard("A", "R[B = 1] -> A", c("C", "R"), c("C", "R")), "A[C = . , R = . ]")
 	}
 )
-}
